@@ -21,12 +21,6 @@
 #define YAF_ROUTE_ASSEMBLE_ACTION_FORMAT ":a"
 #define YAF_ROUTE_ASSEMBLE_CONTROLLER_FORMAT ":c"
 
-#define YAF_ROUTE_PROPETY_NAME_MATCH  	"_route"
-#define YAF_ROUTE_PROPETY_NAME_ROUTE  	"_default"
-#define YAF_ROUTE_PROPETY_NAME_MAP	 	"_maps"
-#define YAF_ROUTE_PROPETY_NAME_VERIFY 	"_verify"
-#define YAF_ROUTE_PROPETY_NAME_REVERSE 	"_reverse"
-
 YAF_BEGIN_ARG_INFO_EX(yaf_route_route_arginfo, 0, 0, 1)
 	YAF_ARG_INFO(0, request)
 YAF_END_ARG_INFO()
@@ -36,10 +30,9 @@ YAF_BEGIN_ARG_INFO_EX(yaf_route_assemble_arginfo, 0, 0, 1)
 	YAF_ARG_ARRAY_INFO(0, query, 1)
 YAF_END_ARG_INFO()
 
-
 extern zend_class_entry *yaf_route_ce;
 
-yaf_route_t * yaf_route_instance(yaf_route_t *this_ptr, HashTable *config);
+int yaf_route_instance(yaf_route_t *route, HashTable *config);
 
 YAF_STARTUP_FUNCTION(route);
 
