@@ -417,7 +417,7 @@ static zend_class_entry *yaf_dispatcher_get_controller(zend_string *app_dir, yaf
 		directory_len += yaf_compose_2_pathes(directory + directory_len, module, ZEND_STRL(YAF_CONTROLLER_DIRECTORY_NAME));
 	}
 
-	STR_ALLOCA_ALLOC(lc_name, ZSTR_LEN(controller) + YAF_G(name_separator_len) + sizeof("Controller") - 1, use_heap);
+	STR_ALLOCA_ALLOC(lc_name, ZSTR_LEN(controller) + YAF_G(name_separator_len) + sizeof("controller") - 1, use_heap);
 	if (EXPECTED(yaf_is_name_suffix())) {
 		char *p = ZSTR_VAL(lc_name);
 		zend_str_tolower_copy(p, ZSTR_VAL(controller), ZSTR_LEN(controller));
@@ -435,7 +435,7 @@ static zend_class_entry *yaf_dispatcher_get_controller(zend_string *app_dir, yaf
 			zend_str_tolower_copy(p, YAF_G(name_separator), YAF_G(name_separator_len));
 			p += YAF_G(name_separator_len);
 		}
-		zend_str_tolower_copy(p, ZSTR_VAL(controller), ZSTR_LEN(controller) + 1);
+		zend_str_tolower_copy(p, ZSTR_VAL(controller), ZSTR_LEN(controller));
 	}
 
 	if ((ce = zend_hash_find_ptr(EG(class_table), lc_name)) == NULL || !instanceof_function(ce, yaf_controller_ce)) {
@@ -475,7 +475,7 @@ static zend_class_entry *yaf_dispatcher_get_action(zend_string *app_dir, yaf_con
 		zend_string *lc_name;
 		ALLOCA_FLAG(use_heap);
 
-		STR_ALLOCA_ALLOC(lc_name, ZSTR_LEN(action) + YAF_G(name_separator_len) + sizeof("Action") - 1, use_heap);
+		STR_ALLOCA_ALLOC(lc_name, ZSTR_LEN(action) + YAF_G(name_separator_len) + sizeof("action") - 1, use_heap);
 		if (EXPECTED(yaf_is_name_suffix())) {
 			char *p = ZSTR_VAL(lc_name);
 			memcpy(p, ZSTR_VAL(action), ZSTR_LEN(action));
@@ -614,8 +614,8 @@ static ZEND_HOT int yaf_dispatcher_handle(yaf_dispatcher_object *dispatcher) /*
 					/* Fallback to lowercase searching */
 					zend_str_tolower(func_name, ZSTR_LEN(request->action));
 					if ((fptr = zend_hash_str_find_ptr(&((ce)->function_table), func_name, func_len)) == NULL) {
-						free_alloca(func_name, use_heap);
 						if (UNEXPECTED((fptr = yaf_dispatcher_handle_action(app, dispatcher, &controller)) == NULL)) {
+							free_alloca(func_name, use_heap);
 							OBJ_RELEASE(Z_OBJ(controller));
 							return 0;
 						}
@@ -687,11 +687,17 @@ static ZEND_HOT int yaf_dispatcher_handle(yaf_dispatcher_object *dispatcher) /*
 /* }}} */
 
 static ZEND_COLD zend_never_inline void yaf_dispatcher_exception_handler(yaf_dispatcher_object *dispatcher) /* {{{ */ {
-	zend_string *exception_str, *controller, *action;
+	zend_string *controller, *action;
 	zval exception;
 	const zend_op *opline;
 	yaf_request_object *request = Z_YAFREQUESTOBJ(dispatcher->request);
 
+#if PHP_VERSION_ID >= 80000
+	if (zend_is_unwind_exit(EG(exception))) {
+		return;
+	}
+#endif
+
 	if ((YAF_DISPATCHER_FLAGS(dispatcher) & YAF_DISPATCHER_IN_EXCEPTION)|| !EG(exception)) {
 		return;
 	}
@@ -718,12 +724,10 @@ static ZEND_COLD zend_never_inline void yaf_dispatcher_exception_handler(yaf_dis
 	zend_string_release(action);
 
 	/** use $request->getException() instand of */
-	exception_str = zend_string_init(ZEND_STRL("exception"), 0);
-	if (yaf_request_set_params_single(request, exception_str, &exception)) {
+	if (yaf_request_set_str_params_single(request, "exception", sizeof("exception") - 1, &exception)) {
 		zval_ptr_dtor(&exception);
 	} else {
 		/* failover to uncaught exception */
-		zend_string_release(exception_str);
 		EG(exception) = Z_OBJ(exception);
 		YAF_DISPATCHER_FLAGS(dispatcher) = ~YAF_DISPATCHER_IN_EXCEPTION;
 		return;
@@ -731,8 +735,7 @@ static ZEND_COLD zend_never_inline void yaf_dispatcher_exception_handler(yaf_dis
 	yaf_request_set_dispatched(request, 0);
 
 	if (UNEXPECTED(!yaf_dispatcher_init_view(dispatcher, NULL, NULL))) {
-		yaf_request_del_param(request, exception_str);
-		zend_string_release(exception_str);
+		yaf_request_del_str_param(request, "exception", sizeof("exception") - 1);
 		YAF_DISPATCHER_FLAGS(dispatcher) = ~YAF_DISPATCHER_IN_EXCEPTION;
 		return;
 	}
@@ -749,8 +752,7 @@ static ZEND_COLD zend_never_inline void yaf_dispatcher_exception_handler(yaf_dis
 		}
 	}
 
-	yaf_request_del_param(request, exception_str);
-	zend_string_release(exception_str);
+	yaf_request_del_str_param(request, "exception", sizeof("exception") - 1);
 
 	if (!(YAF_DISPATCHER_FLAGS(dispatcher) & YAF_DISPATCHER_RETURN_RESPONSE)) {
 		yaf_response_response(Z_YAFRESPONSEOBJ(dispatcher->response));
